@@ -9,7 +9,7 @@
 package WebService::HashiCorp::Vault;
 
 use Moo;
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 extends 'WebService::HashiCorp::Vault::Base';
 use namespace::clean;
@@ -48,9 +48,10 @@ use WebService::HashiCorp::Vault::Sys;
 sub secret {
     my $self = shift;
     my %args = @_;
-    $args{token}   = $self->token();
-    $args{version} = $self->version();
-    $args{path}    = $self->path();
+    $args{token}    = $self->token();
+    $args{version}  = $self->version();
+    $args{base_url} = $self->base_url();
+
     $args{backend} ||= 'generic';
     die sprintf( "Unknown backend type: %s\n", $args{backend} )
         unless $backendmap{ lc($args{backend}) };
@@ -65,9 +66,11 @@ sub secret {
 sub sys {
     my $self = shift;
     my %args = @_;
-    $args{mount} ||= 'sys';
-    $args{token} = $self->token();
-    $args{version} = $self->version();
+    $args{mount}    ||= 'sys';
+    $args{token}    = $self->token();
+    $args{version}  = $self->version();
+    $args{base_url} = $self->base_url();
+
     return WebService::HashiCorp::Vault::Sys->new( %args );
 }
 
@@ -86,7 +89,7 @@ WebService::HashiCorp::Vault - Perl API for HashiCorp's Vault
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -122,9 +125,9 @@ Unfortunatly the "official" API's for other languages aren't much to go on. They
 =head2 secret
 
  my $secret = $vault->secret(
-     mount   => 'secret', # optional if mounted non-default
+     mount   => 'secret',  # optional if mounted non-default
      backend => 'Generic', # or MySQL, or SSH, or whatever
-     path    => 'my_service' # optional secret path
+     %other_args,          # other, backend specific arguments
  );
 
 B<Parameters>
@@ -161,6 +164,10 @@ Here are the currently supported options:
 
 =back
 
+=item other arguments
+
+See the documentation for the backend in question. Everything will pass through to the backend's constructor.
+
 =back
 
 B<Returns>
